<?php
/*
Plugin Name: I18N Special Pages extras
Description: This plugin allows you to control which special page fields are required also it allows you to add additional info text next to custom field label, show thumbnail preview if field is image type and set some page options like: title label, content label, hide keywords and meta descriptions fields etc.
Version: 1.05
Author: Michał Gańko
Author URI: http://foureyes.pl
*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 
	'I18N Special Pages extras', 	
	'1.05', 		
	'Michał Gańko',
	'http://foureyes.pl', 
	'This plugin allows you to control which special page fields are required also it allows you to add additional info text next to custom field label, show thumbnail preview if field is image type and set some page options like: title label, content label, hide keywords and meta descriptions fields etc.'
);

//override i18n_specialpages start function
$plugin_info['i18n_specialpages']['load_data'] = 'spe_i18n_specialpages_main';

//modified special pages function
function spe_i18n_specialpages_main() {
    require_once(GSPLUGINPATH.'i18n_specialpages/specialpages.class.php');
    if (isset($_GET['create'])) {
    include(GSPLUGINPATH.'i18n_specialpages/create.php');
    } else if (isset($_GET['pages'])) {
    include(GSPLUGINPATH.'i18n_specialpages/pages.php');
    } else if (isset($_GET['config']) && isset($_GET['edit'])) {
    include(GSPLUGINPATH.'i18n_specialpages/conf_edit.php');
    } else if (isset($_GET['config']) && isset($_GET['settings'])) {
    include(GSPLUGINPATH.'i18n_specialpages/conf_settings.php');
    } else if (isset($_GET['config'])) {
    include(GSPLUGINPATH.'i18n_specialpages/conf_overview.php');
    }
    
    if ( isset($_GET['config']) ){
        require_once('SpecialPagesExtras/SPEClass.php');
        $spe = SPEClass::getInstance();
    
        //was undo and success ($success is from i18n_specialpages/pages.php file)
        if (isset($_GET['edit']) && isset($_GET['undo']) && !isset($_POST['save']) && @$success ){
            $spe->confUndo();
        }
        else if (isset($_GET['edit']) && isset($_POST['save']) && @$success ) {  //was save and success
            $spe->confSave();
        }   
        else if (isset($_GET['delete']) && @$success ) {  //was save and success
            $spe->confDelete();
        }  
    }
}


if (!is_frontend()){
    $spe_currFile = strtolower(basename($_SERVER['PHP_SELF'])); //currently loadded file

    global $LANG;
    i18n_merge('SpecialPagesExtras', substr($LANG,0,2)) || i18n_merge('SpecialPagesExtras','en');

    add_action('header', 'spe_on_header'); 
    add_action('footer', 'spe_on_footer'); 
    
    add_action('edit-extras', 'spe_on_edit_extras'); 
    
    
    //if saving page and its special page, security check functions
    if ($spe_currFile == 'changedata.php' && @$_POST['post-special']) {
        require_once('SpecialPagesExtras/SPEClass.php');
        $spe = SPEClass::getInstance();
        $spe->editSaveSecurityCheck();
    }   


    if ($spe_currFile == 'deletefile.php') {
        if ( isset($_GET['file']) ){
        
            $path = (isset($_GET['path'])) ? $_GET['path'] : '';
            $id = $_GET['file'];            
            $filepath = GSDATAUPLOADPATH . $path;
            $file =  $filepath . $id;
    
            //check that path is safe, etc.
            if(path_is_safe($filepath,GSDATAUPLOADPATH) && filepath_is_safe($file,$filepath)){
                if ( file_exists(GSDATAOTHERPATH . 'SpecialPagesExtras/thumbs/data/uploads/'.$path . $id) ) { //delete thumb
                    unlink(GSDATAOTHERPATH . 'SpecialPagesExtras/thumbs/data/uploads/'.$path . $id);
                }      
                if ( file_exists(GSDATAOTHERPATH . 'SpecialPagesExtras/thumbs/data/thumbs/'.$path . 'thumbnail.'.$id) ) { //delete thumb for thumbnail 
                    unlink(GSDATAOTHERPATH . 'SpecialPagesExtras/thumbs/data/thumbs/'.$path . 'thumbnail.'.$id);
                }
            }	
 
        }
        else if ( isset($_GET['folder']) ){ //removing empty folder
            $path = (isset($_GET['path'])) ? $_GET['path'] : '';
            $folder = $_GET['folder'];
            $target = GSDATAUPLOADPATH . $path . $folder;
            
            //check that path is safe for uploads
            if (path_is_safe($target,GSDATAUPLOADPATH) && file_exists($target)) {
                //removes empty directory, so we believe that all thumbs from that dir was deleted when user deleted files by admin panel
                @rmdir(GSDATAOTHERPATH . 'SpecialPagesExtras/thumbs/data/uploads/'.$path . $folder);
            }
        }
    }
    
    
}

function spe_on_header(){
    global $spe_currFile;
    
    if ( $spe_currFile == 'edit.php'  ){
        require_once('SpecialPagesExtras/SPEClass.php');
        $spe = SPEClass::getInstance();
        $spe->editHeader();
    }   

    if ( $spe_currFile == 'load.php' && @$_GET['id'] == 'i18n_specialpages' && isset($_GET['config']) && isset($_GET['edit']) ){
        require_once('SpecialPagesExtras/SPEClass.php');
        $spe = SPEClass::getInstance();
        $spe->confHeader();
    }
}

function spe_on_footer(){
    global $spe_currFile;

    //if in edition special page
    if ( $spe_currFile == 'load.php' && @$_GET['id'] == 'i18n_specialpages' && isset($_GET['config']) && isset($_GET['edit']) ){
        $spe = SPEClass::getInstance();
        $spe->confFooter();
    }
}

function spe_on_edit_extras(){
    global $data_edit;
    $spname = null;
    
    //copied and little modified form 18n special pages
    if (isset($_GET['special'])) {
        // create a special page or change the type of page
        $spname = $_GET['special'];
    } else if (isset($data_edit) && isset($data_edit->special) && (string) $data_edit->special) {
        // edit a special page
        $spname = (string) $data_edit->special;
    } else if (isset($_GET['newid']) && strpos($_GET['newid'],'_') > 0) {
        // this language page should be the same as the default language page
        $id_base = substr($_GET['newid'], 0, strrpos($_GET['newid'],'_'));
        $data_base = getXML(GSDATAPAGESPATH . $id_base . '.xml');
        if (isset($data_base) && isset($data_base->special) && (string) $data_base->special) {
          $spname = (string) $data_base->special;
        }
    }
        
    if ( $spname ){
        require_once('SpecialPagesExtras/SPEClass.php');
        $spe = SPEClass::getInstance();
        $spe->editExtras($spname); 
    }
}



